JsonRpcParser

Struct JsonRpcParser 

pub struct JsonRpcParser;
JSON-RPC parser

Implementations

Source

impl JsonRpcParser

pub fn parse_request(json: &str) -> Result<JsonRpcRequest, JsonRpcParseError>

Parse a JSON-RPC request from a string

pub fn parse_request_with_limit( json: &str, max_size: usize, ) -> Result<JsonRpcRequest, JsonRpcParseError>

Parse a JSON-RPC request from a string with a maximum byte size.

pub fn parse_request_value( value: &Value, ) -> Result<JsonRpcRequest, JsonRpcParseError>

Parse a JSON-RPC request from a Value

pub fn parse_response(json: &str) -> Result<JsonRpcResponse, JsonRpcParseError>

Parse a JSON-RPC response from a string

pub fn parse_response_with_limit( json: &str, max_size: usize, ) -> Result<JsonRpcResponse, JsonRpcParseError>

Parse a JSON-RPC response from a string with a maximum byte size.

pub fn parse_response_value( value: &Value, ) -> Result<JsonRpcResponse, JsonRpcParseError>

Parse a JSON-RPC response from a Value

pub fn format_request( request: &JsonRpcRequest, ) -> Result<String, JsonRpcParseError>

Format a request to JSON string

pub fn format_response( response: &JsonRpcResponse, ) -> Result<String, JsonRpcParseError>

Format a response to JSON string