SharedArgs

Struct SharedArgs 

pub struct SharedArgs<'a> { /* private fields */ }
Shared arguments for zero-copy access

Implementations

Source

impl<'a> SharedArgs<'a>

pub fn new(data: &'a [u8], layout: u64) -> Self

Create new shared args from bytes and layout

pub fn data(&self) -> &[u8]

Get the raw data slice

pub fn layout(&self) -> u64

Get the argument layout

pub fn read_str_at(&self, offset: usize, len: usize) -> Result<&str, DCPError>

Read a string at the given offset with bounds checking

pub fn read_i32_at(&self, offset: usize) -> Result<i32, DCPError>

Read an i32 at the given offset with bounds checking

pub fn read_i64_at(&self, offset: usize) -> Result<i64, DCPError>

Read an i64 at the given offset with bounds checking

pub fn read_u32_at(&self, offset: usize) -> Result<u32, DCPError>

Read a u32 at the given offset with bounds checking

pub fn read_bytes_at( &self, offset: usize, len: usize, ) -> Result<&[u8], DCPError>

Read bytes at the given offset with bounds checking

pub fn read_bool_at(&self, offset: usize) -> Result<bool, DCPError>

Read a bool at the given offset

pub fn read_f64_at(&self, offset: usize) -> Result<f64, DCPError>

Read an f64 at the given offset with bounds checking