MultiplexedConnection

Struct MultiplexedConnection 

pub struct MultiplexedConnection { /* private fields */ }
Multiplexed connection supporting concurrent streams

Implementations

Source

impl MultiplexedConnection

pub fn new() -> Self

Create a new multiplexed connection

pub fn with_max_send_queue_len(max_send_queue_len: usize) -> Self

Create a new multiplexed connection with a bounded outbound frame queue.

pub fn with_max_recv_buffer_bytes(max_recv_buffer_bytes: usize) -> Self

Create a new multiplexed connection with a bounded receive buffer.

pub fn with_limits( max_send_queue_len: usize, max_recv_buffer_bytes: usize, ) -> Self

Create a new multiplexed connection with explicit transport limits.

pub fn is_closed(&self) -> bool

Check if connection is closed

pub fn stream_count(&self) -> u16

Get current stream count

pub async fn open_stream(&self) -> Result<u16, MultiplexError>

Open a new stream

pub async fn accept_stream(&self, stream_id: u16) -> Result<(), MultiplexError>

Accept an incoming stream (called when receiving SYN)

pub async fn send( &self, stream_id: u16, data: Bytes, ) -> Result<(), MultiplexError>

Send data on a stream

pub async fn recv( &self, stream_id: u16, ) -> Result<Option<Bytes>, MultiplexError>

Receive data from a stream

pub async fn close_stream(&self, stream_id: u16) -> Result<(), MultiplexError>

Close a stream gracefully

pub async fn reset_stream( &self, stream_id: u16, error: Option<String>, ) -> Result<(), MultiplexError>

Reset a stream with error

pub async fn process_frame( &self, header: StreamHeader, payload: Bytes, ) -> Result<(), MultiplexError>

Process an incoming frame

pub async fn take_frame(&self) -> Option<(StreamHeader, Bytes)>

Take next frame to send

pub fn encode_frame(header: &StreamHeader, payload: &Bytes) -> Bytes

Encode a frame to bytes

pub async fn stream_status( &self, stream_id: u16, ) -> Result<StreamStatus, MultiplexError>

Get stream status

pub async fn close(&self)

Close the connection

pub fn total_bytes_sent(&self) -> u64

Get total bytes sent

pub fn total_bytes_received(&self) -> u64

Get total bytes received

pub async fn has_stream(&self, stream_id: u16) -> bool

Check if a stream exists

pub async fn active_streams(&self) -> Vec<u16>

Get all active stream IDs