SchemaValidator

Struct SchemaValidator 

pub struct SchemaValidator;
Schema validator

Implementations

Source

impl SchemaValidator

pub fn validate_required( schema: &InputSchema, present_mask: u64, ) -> Result<(), DCPError>

Validate that all required fields are present present_mask is a bitmask where bit N indicates field N is present

pub fn validate_enum(field: &FieldDef, value: u8) -> Result<(), DCPError>

Validate an enum value is within range

pub fn validate_input( schema: &InputSchema, present_mask: u64, field_values: &[(usize, u8)], ) -> Result<(), DCPError>

Validate a complete input against schema

pub fn validate_shared_args( schema: &InputSchema, args: &SharedArgs<'_>, ) -> Result<(), DCPError>

Validate shared binary arguments against a tool input schema.