ResourceRegistry

Struct ResourceRegistry 

pub struct ResourceRegistry { /* private fields */ }
Resource registry for managing handlers and subscriptions

Implementations

Source

impl ResourceRegistry

pub fn new() -> Self

Create a new resource registry

pub fn register( &mut self, handler: impl ResourceHandler + 'static, ) -> Result<u16, ResourceError>

Register a resource handler

pub fn handler_count(&self) -> usize

Get the number of registered handlers

pub fn match_uri(&self, uri: &str) -> Option<&dyn ResourceHandler>

Find a handler that matches the given URI

pub fn handler_id_for_uri(&self, uri: &str) -> Option<u16>

Find the registered capability ID for the handler matching the URI.

pub fn handler_ids(&self) -> Vec<u16>

Registered resource capability IDs.

pub fn allowed_uri_templates<F>(&self, allow_handler: F) -> Vec<String>
where F: FnMut(u16) -> bool,

URI templates for registered handlers accepted by a capability predicate.

pub fn any_allowed_supports_subscribe<F>(&self, allow_handler: F) -> bool
where F: FnMut(u16) -> bool,

Whether any accepted handler supports resource subscriptions.

pub fn list_all( &self, cursor: Option<&str>, ) -> Result<ResourceList, ResourceError>

List all resources from all handlers

pub fn list_allowed<F>( &self, cursor: Option<&str>, allow_handler: F, ) -> Result<ResourceList, ResourceError>
where F: FnMut(u16) -> bool,

List resources from handlers accepted by a capability predicate.

pub fn read(&self, uri: &str) -> Result<ResourceContent, ResourceError>

Read a resource by URI

pub fn ensure_subscribable(&self, uri: &str) -> Result<(), ResourceError>

Validate that a concrete resource URI is eligible for subscriptions.

pub async fn subscribe<F>( &self, uri: &str, callback: F, ) -> Result<SubscriptionId, ResourceError>
where F: Fn(&str) + Send + Sync + 'static,

Subscribe to resource changes

pub async fn unsubscribe(&self, id: SubscriptionId) -> bool

Unsubscribe from resource changes

pub async fn notify_change(&self, uri: &str)

Notify all subscribers of a resource change

pub async fn subscription_count(&self, uri: &str) -> usize

Get subscription count for a URI