pub struct SecurityAuditLog { /* private fields */ }Expand description
Bounded in-memory audit log used by adapters and tests.
Implementations
Sourceimpl SecurityAuditLog
impl SecurityAuditLog
Sourcepub fn with_capacity(max_events: usize) -> Self
pub fn with_capacity(max_events: usize) -> Self
Create an empty audit log with a maximum retained event count.
Sourcepub fn record(&self, event: SecurityAuditEvent)
pub fn record(&self, event: SecurityAuditEvent)
Append an event.
Sourcepub fn events(&self) -> Vec<SecurityAuditEvent>
pub fn events(&self) -> Vec<SecurityAuditEvent>
Snapshot events.
Sourcepub fn dropped_count(&self) -> u64
pub fn dropped_count(&self) -> u64
Number of receipts dropped because the retention bound was reached.