pub struct SchemaValidator;Expand description
Schema validator
Implementations
Sourceimpl SchemaValidator
impl SchemaValidator
Sourcepub fn validate_required(
schema: &InputSchema,
present_mask: u64,
) -> Result<(), DCPError>
pub fn validate_required( schema: &InputSchema, present_mask: u64, ) -> Result<(), DCPError>
Validate that all required fields are present
present_mask is a bitmask where bit N indicates field N is present
Sourcepub fn validate_enum(field: &FieldDef, value: u8) -> Result<(), DCPError>
pub fn validate_enum(field: &FieldDef, value: u8) -> Result<(), DCPError>
Validate an enum value is within range
Sourcepub fn validate_input(
schema: &InputSchema,
present_mask: u64,
field_values: &[(usize, u8)],
) -> Result<(), DCPError>
pub fn validate_input( schema: &InputSchema, present_mask: u64, field_values: &[(usize, u8)], ) -> Result<(), DCPError>
Validate a complete input against schema
Validate shared binary arguments against a tool input schema.